Changelog
=========


1.0.2 (2017-06-08)
------------------

- Add Polygon and Line into boundary box widget.
  [bsuttor]


1.0.1 (2017-04-26)
------------------

- Intialize markers before used it.
  [bsuttor]


1.0.0 (2017-03-28)
------------------

- Add faceted boundary bounds widget.
  [bsuttor]


1.0a5 (2016-11-18)
------------------

- Do not show the map viewlet container if json data is unavailable
  [mpeeters]


1.0a4 (2016-09-20)
------------------

- Use adapter for getting geomap settings.
  [bsuttor]


1.0a3 (2016-09-08)
------------------

- Do not batch faceted results.
  [bsuttor]

- Add MarkerCluster.
  [bsuttor]


1.0a2 (2016-09-08)
------------------

- Create test profile.
  [bsuttor]


1.0a1 (2016-09-07)
------------------

- Initial release.
  [bsuttor]
